from setuptools import setup, find_packages

setup(
    name='show_table_logs',
    version='0.1',
    packages=find_packages(),
    description='A library to create two files with specific content',
    author='SINTT',
    author_email='bbhh66606@gmail.com',
    install_requires=[],
)
